faker\_file.providers.augment\_file\_from\_dir.extractors package
=================================================================

Submodules
----------

faker\_file.providers.augment\_file\_from\_dir.extractors.tika\_extractor module
--------------------------------------------------------------------------------

.. automodule:: faker_file.providers.augment_file_from_dir.extractors.tika_extractor
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: faker_file.providers.augment_file_from_dir.extractors
   :members:
   :undoc-members:
   :show-inheritance:
